==> lxqt-config-0.15.0.tar.xz: lxqt-config-0.15.0/lxqt-config-input/translations/lxqt-config-input_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Temps de parpelleig del cursor:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teclat&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>So d&apos;avís quan hi hagi un error de l&apos;entrada del teclat</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Repetició de caràcters</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="79"/>
        <location filename="../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Llarg</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Retard de repetició:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="115"/>
        <location filename="../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Breu</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Interval de repetició:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Teclegeu en el següent requadre per a provar els vostres ajusts del teclat</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="150"/>
        <location filename="../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Engega «Bloq Núm» a l&apos;inici de la sessió</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Disposició de teclat&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Disposició</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Variant</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Afegeix</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>Sup&amp;rimeix</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="77"/>
        <source>Up</source>
        <translation>Amunt</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="84"/>
        <source>Down</source>
        <translation>Avall</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Model del teclat:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Tecles per canviar la disposició:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Sense</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nota&lt;/span&gt;: Si esteu utilitzant un &lt;span style=&quot; font-weight:600;&quot;&gt;mètode d&apos;entrada&lt;/span&gt;, com ara IBus, uim, fcitx, o gcin, els ajusts que feu aquí &lt;span style=&quot; font-weight:600;&quot;&gt;pot ser que no funcionin&lt;/span&gt; perquè són anul·lats pels mètodes d&apos;entrada.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ratolí&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="30"/>
        <source>Motion</source>
        <translation>Moviment</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="36"/>
        <source>High</source>
        <translation>Alta</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="43"/>
        <source>Fast</source>
        <translation>Ràpida</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="50"/>
        <source>Sensitivity:</source>
        <translation>Sensibilitat:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="57"/>
        <source>Low</source>
        <translation>Baixa</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="83"/>
        <source>Acceleration:</source>
        <translation>Acceleració:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="109"/>
        <source>Slow</source>
        <translation>Lenta</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="116"/>
        <location filename="../mouseconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="133"/>
        <source>Double click interval:</source>
        <translation>Interval de temps del doble clic:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="140"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="150"/>
        <source>Wheel scroll lines:</source>
        <translation>Línies de desplaçament de la roda:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="160"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Esquerrer (intercanvia el botó esquerre i dret del ratolí)</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="167"/>
        <source>Single click to activate items</source>
        <translation>Un sol clic per activar els ítems</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqt-config-input.cpp" line="70"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Ajusts del teclat i del ratolí</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="79"/>
        <source>Mouse</source>
        <translation>Ratolí</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="88"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="95"/>
        <source>Keyboard</source>
        <translation>Teclat</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="103"/>
        <source>Keyboard Layout</source>
        <translation>Disposició de teclat</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="112"/>
        <source>Mouse and Touchpad</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Seleccioneu una disposició de teclat</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Disposició de teclat</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Variant</translation>
    </message>
</context>
<context>
    <name>TouchpadConfig</name>
    <message>
        <location filename="../touchpadconfig.ui" line="14"/>
        <source>TouchpadConfig </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="20"/>
        <source>Device:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="30"/>
        <source>Acceleration speed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="37"/>
        <source>Tap to click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="44"/>
        <source>Natural Scrolling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="51"/>
        <source>Tap and drag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="79"/>
        <source>Scrolling:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="102"/>
        <source>&amp;Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="109"/>
        <source>&amp;Two-Finger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="116"/>
        <source>Ed&amp;ge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="123"/>
        <source>B&amp;utton</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-config-2.2.0.tar.xz: lxqt-config-2.2.0/lxqt-config-input/translations/lxqt-config-input_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="143"/>
        <source>Cursor flash time:</source>
        <translation>Temps de parpelleig del cursor:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Teclat&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="160"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>So d&apos;avís quan hi hagi un error de l&apos;entrada del teclat</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="150"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="27"/>
        <source>Character Repeat</source>
        <translation>Repetició de caràcters</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="69"/>
        <location filename="../keyboardconfig.ui" line="116"/>
        <source>Long</source>
        <translation>Llarg</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="33"/>
        <source>Repeat delay:</source>
        <translation>Retard de repetició:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="40"/>
        <location filename="../keyboardconfig.ui" line="90"/>
        <source>Short</source>
        <translation>Breu</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="83"/>
        <source>Repeat interval:</source>
        <translation>Interval de repetició:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="130"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Teclegeu en el següent requadre per a provar els vostres ajusts del teclat</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="76"/>
        <location filename="../keyboardconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Engega «Bloq Núm» a l&apos;inici de la sessió</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Disposició de teclat&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Disposició</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Variant</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Afegeix</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>Sup&amp;rimeix</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="77"/>
        <source>Up</source>
        <translation>Amunt</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="84"/>
        <source>Down</source>
        <translation>Avall</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Model del teclat:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Tecles per canviar la disposició:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Sense</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nota&lt;/span&gt;: Si esteu utilitzant un &lt;span style=&quot; font-weight:600;&quot;&gt;mètode d&apos;entrada&lt;/span&gt;, com ara IBus, uim, fcitx, o gcin, els ajusts que feu aquí &lt;span style=&quot; font-weight:600;&quot;&gt;pot ser que no funcionin&lt;/span&gt; perquè són anul·lats pels mètodes d&apos;entrada.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Formulari</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Ratolí&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="30"/>
        <source>Double click interval:</source>
        <translation>Interval de temps del doble clic:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="37"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="47"/>
        <source>Wheel scroll lines:</source>
        <translation>Línies de desplaçament de la roda:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="64"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Esquerrer (intercanvia el botó esquerre i dret del ratolí)</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="57"/>
        <source>Single click to activate items</source>
        <translation>Un sol clic per activar els ítems</translation>
    </message>
    <message>
        <location filename="../mouseconfig.cpp" line="65"/>
        <source>Use the settings of the Wayland compositor for more options about mouse, touchpad and keyboard.</source>
        <translation>Usa la configuració del compositor Wayland per obtenir més opcions sobre el ratolí, el ratolí tàctil i el teclat.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqt-config-input.cpp" line="39"/>
        <source>LXQt input settings are currently unsupported under Wayland.

Mouse, touchpad and keyboard can be configured in the settings of the compositor.</source>
        <translation>Actualment, la configuració d&apos;entrada d&apos;LXQt no és compatible amb Wayland.

El ratolí, el ratolí tàctil i el teclat es poden configurar a la configuració del compositor.</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="76"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Ajusts del teclat i del ratolí</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="94"/>
        <source>Mouse</source>
        <translation>Ratolí</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="103"/>
        <source>Cursor</source>
        <translation>Cursor</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="108"/>
        <source>To apply the changes also to GTK, check LXQt Appearance Configuration → GTK Style.</source>
        <translation>Per aplicar els canvis també a GTK, marqueu Configuració d&apos;aparença LXQt → Estil GTK.</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="112"/>
        <source>Keyboard</source>
        <translation>Teclat</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="123"/>
        <source>Keyboard Layout</source>
        <translation>Disposició de teclat</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="136"/>
        <source>Mouse and Touchpad</source>
        <translation>Ratolí i ratolí tàctil</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Seleccioneu una disposició de teclat</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Disposició de teclat</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Variant</translation>
    </message>
</context>
<context>
    <name>TouchpadConfig</name>
    <message>
        <location filename="../touchpadconfig.ui" line="14"/>
        <source>TouchpadConfig </source>
        <translation>Configuració del ratolí tàctil </translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="20"/>
        <source>Device:</source>
        <translation>Dispositiu:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="37"/>
        <source>Acceleration speed:</source>
        <translation>Velocitat d&apos;acceleració:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="60"/>
        <source>Tap to click</source>
        <translation>Toca per fer clic</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="67"/>
        <source>Natural Scrolling</source>
        <translation>Desplaçament natural</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="74"/>
        <source>Tap and drag</source>
        <translation>Toca i arrossega</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="86"/>
        <source>Scrolling:</source>
        <translation>Desplaçament:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="109"/>
        <source>&amp;Disabled</source>
        <translation>&amp;Inhabilitat</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="116"/>
        <source>&amp;Two-Finger</source>
        <translation>&amp;Dos dits</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="123"/>
        <source>Ed&amp;ge</source>
        <translation>&amp;Vora</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="130"/>
        <source>B&amp;utton</source>
        <translation>&amp;Botó</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="30"/>
        <source>DeviceInfoLabel</source>
        <translation>Etiqueta d&apos;informació del dispositiu</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.cpp" line="85"/>
        <source>LXQt only supports &quot;libinput&quot; as xinput driver.
(current value: %1)

If this is intended, please configure xinput manually.
Otherwise you can get rid of this message by changing xinput driver to &quot;libinput&quot;.
</source>
        <translation>LXQt només admet «libinput» com a controlador de xinput.
(valor actual:%1)

Si així ho desitja, configureu xinput manualment.
En cas contrari, podeu desfer-vos d&apos;aquest missatge canviant el controlador xinput a &quot;libinput&quot;.
</translation>
    </message>
</context>
</TS>
